@@ -131,7 +131,7 @@ def store_temporary_asset(state):
             # Thumbnail
             if variations:
                 variations['--thumb--'] = flask.current_app.config.get(
-                    'ASSET_DRAFT_VARIATION',
+                    'ASSET_THUMB_VARIATION',
                     [
                         Fit(480),
                         Output('jpg', 75)
